# Tests by default. No tests: rpm -ba --define 'dotests 0' *.spec

%{!?dotests: %define dotests 0}

%global __tar /opt/freeware/bin/tar
%global _libdir64 %{_prefix}/lib64
%global name xgboost
%global version 2.1.3
%global release 1 

#python releated configs
%global py_major 3.9
%global py_minor 18

%global python_major python%{py_major}

%global python3_sitearch %(%{python_major} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(0))")
%global python3_sitearch64 %(%{python_major} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")

Name:           %{name}
Version:        %{version}
Release:        %{release}
Summary:        eXtreme Gradient Boosting
License:        Apache-2.0
URL:            https://xgboost.ai
Source0:        https://github.com/dmlc/xgboost/releases/download/v%{version}/xgboost-%{version}.tar.gz
Source1:        dmlc-core-13341857549852a9a86b1894b5ba84c6276ab381.tar.gz
Source3:        https://github.com/rapidsai/gputreeshap/archive/refs/tags/v22.02.00.tar.gz

Patch0:         xgboost-2.1.3-aix-support.patch
Patch1:         xgboost-2.1.3-test-fix.patch
Patch2:         xgboost-2.1.3-PR-11021-for-scikit-learn-1.6-backport.patch


BuildRequires:  cmake >= 3.30.3
BuildRequires:  gtest-devel >= 1.15.2

%if %{toolchain} == "gcc"
Requires: 	libstdc++ >= 10
Requires: 	libgcc >= 10
%endif
Requires: 	libgomp >= 10

%description
XGBoost is an optimized distributed gradient boosting library designed to be highly efficient, flexible and portable. 
It implements machine learning algorithms under the Gradient Boosting framework. 
XGBoost provides a parallel tree boosting (also known as GBDT, GBM) that solve many data science problems in a fast and accurate way.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
Development headers for %{name}.

%package python3
Summary:        xgboost Python Package
Group:          Development/Libraries/Python

BuildRequires:  %{python_major}-devel >= %{py_major}.%{py_minor}
BuildRequires:  %{python_major}-setuptools >= 72.1.0
Requires:       %{name} = %{version}-%{release}
Requires:       %{python_major} >= %{py_major}.%{py_minor}
Requires:       %{python_major}-numpy >= 2.0.2
Requires:       %{python_major}-scipy >= 1.13.1
%if %{toolchain} == "gcc"
Requires: 	libstdc++ >= 10
Requires: 	libgcc >= 10
%endif
Requires: 	libgomp >= 10

%description python3
This package contains the Python 3 bindings for XGBoost.

%prep
%setup -n  xgboost
%patch0 -p1
%patch1 -p1
%patch2 -p1
%{__tar} -xvf %{SOURCE1}  --strip 1 -C dmlc-core
%{__tar} -xvf %{SOURCE3}  --strip 1 -C gputreeshap

%build
#64bit Build only
export OBJECT_MODE=64
export CC="%{__cc__}" 
export CFLAGS="-maix64 -pthread -maltivec -mvsx -I/opt/freeware/include -fPIC -O2 -I/usr/include "
export CXX="%{__cxx__}" 
export CXXFLAGS="-maix64 -pthread -maltivec -mvsx -I/opt/freeware/include -fPIC -O2 -I/usr/include"
export LDFLAGS="-L/opt/freeware/lib/pthread -L/opt/freeware/lib64 -L/opt/freeware/lib -L/usr/lib"

cmake . -B build \
  -DGOOGLE_TEST=ON\
  -DBUILD_SHARED_LIBS=ON \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DCMAKE_AIX_SHARED_LIBRARY_ARCHIVE=ON 

cmake --build build -j 4

%install
ulimit -m unlimited
ulimit -d unlimited
export DESTDIR=$RPM_BUILD_ROOT
cmake  --install build

#python installation
export OBJECT_MODE=64
export CC="%{__cc__} "
export CFLAGS="-maix64 -pthread -maltivec -mvsx -I/opt/freeware/include -fPIC -O2 -I/usr/include "
export CXX="%{__cxx__} "
export CXXFLAGS="-maix64 -pthread -maltivec -mvsx -I/opt/freeware/include -fPIC -O2 -I/usr/include "
export LDFLAGS="-L/opt/freeware/lib/pthread -L/opt/freeware/lib64 -L/opt/freeware/lib -L/usr/lib"

cd python-package
%{python_major} -m pip install . --root %{buildroot} -vvv -I --no-deps 
cd ..
#python wheel is installing file into python3_sitearch, instead of python3_sitearch64.
#So, making a copy.
install -dm 755 $RPM_BUILD_ROOT/%{python3_sitearch64}/
cp -r $RPM_BUILD_ROOT/%{python3_sitearch}/* $RPM_BUILD_ROOT/%{python3_sitearch64}/.

%check
export LIBPATH=/opt/freeware/lib/pthread:/opt/freeware/lib64:/opt/freeware/lib
cd build
ulimit -m unlimited;ulimit -d unlimited;./testxgboost --gtest_filter=*-AllreduceGlobal.Small:IO.PrivateMmapStream || true

%files
%defattr(-,root,system,-)
%doc README.md LICENSE NEWS.md
%{_libdir}/*.a

%files devel
%defattr(-,root,system,-)
%{_includedir}/xgboost/
%{_includedir}/dmlc/
%{_libdir}/cmake/xgboost
%{_libdir}/pkgconfig/xgboost.pc

%files python3
%defattr(-,root,system,-)
%doc README.md LICENSE NEWS.md
%{python3_sitearch64}/*

%changelog
* Tue Jan 21 2025 Ranjit Ranjan <ranjit.ranjan@ibm.com> - 2.1.3-1
- Update to 2.1.3 and support for numpy 2.0.2.

* Mon May 06 2024 Ranjit Ranjan <ranjit.ranjan@ibm.com> - 1.7.6-1
- Port on AIX.
